@@ -1,7 +1,7 @@
 #
 #  - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 #  SLEPc - Scalable Library for Eigenvalue Problem Computations
-#  Copyright (c) 2002-2021, Universitat Politecnica de Valencia, Spain
+#  Copyright (c) 2002-, Universitat Politecnica de Valencia, Spain
 #
 #  This file is part of SLEPc.
 #  SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -15,16 +15,15 @@ class Primme(package.Package):
   def __init__(self,argdb,log):
     package.Package.__init__(self,argdb,log)
     self.packagename    = 'primme'
+    self.packagetype    = 'source_c'
     self.installable    = True
     self.downloadable   = True
     self.version        = '3.2'
     self.url            = 'https://github.com/primme/primme/archive/v'+self.version+'.tar.gz'
     self.archive        = 'primme-'+self.version+'.tar.gz'
-    self.dirname        = 'primme-'+self.version
     self.supportssingle = True
     self.supports64bint = True
     self.hasheaders     = True
-    self.hasdloadflags  = True
     self.ProcessArgs(argdb)
 
   def SampleCode(self,petsc):
@@ -62,50 +61,54 @@ class Primme(package.Package):
   def Check(self,slepcconf,slepcvars,petsc,archdir):
     code = self.SampleCode(petsc)
     if self.packagedir:
-      dirs = [os.path.join(self.packagedir,'lib'),self.packagedir,os.path.join(self.packagedir,'lib64')]
-      incdirs = [os.path.join(self.packagedir,'include'),self.packagedir]
+      if os.path.isdir(os.path.join(os.sep,'usr','lib64')):
+        dirs = ['',os.path.join(self.packagedir,'lib64'),self.packagedir,os.path.join(self.packagedir,'lib')]
+      else:
+        dirs = ['',os.path.join(self.packagedir,'lib'),self.packagedir,os.path.join(self.packagedir,'lib64')]
+      incdirs = ['',os.path.join(self.packagedir,'include'),self.packagedir]
     else:
-      dirs = self.GenerateGuesses('Primme',archdir)
+      dirs = self.GenerateGuesses('Primme',archdir) + self.GenerateGuesses('Primme',archdir,'lib64')
       incdirs = self.GenerateGuesses('Primme',archdir,'include')
 
-    libs = self.packagelibs
-    if not libs:
-      libs = ['-lprimme']
-    includes = self.packageincludes
-    if not includes:
-      includes = ['.']
+    libs = [self.packagelibs] if self.packagelibs else ['-lprimme']
+    includes = [self.packageincludes] if self.packageincludes else []
 
-    for (d,i) in zip(dirs,incdirs):
-      if d:
-        if petsc.buildsharedlib:
-          l = [petsc.slflag + d] + ['-L' + d] + libs
+    for d in dirs:
+      for i in incdirs:
+        if d:
+          if petsc.buildsharedlib:
+            l = [self.slflag + d] + ['-L' + d] + libs
+          else:
+            l = ['-L' + d] + libs
+          f = (['-I' + i] if i else [])
         else:
-          l = ['-L' + d] + libs
-        f = ['-I' + i]
-      else:
-        l = libs
-        f = ['-I' + includes[0]]
-      result = self.Link([],[],l+f,code,' '.join(f),petsc.language)
-      if result:
-        slepcconf.write('#define SLEPC_HAVE_PRIMME 1\n')
-        slepcvars.write('PRIMME_LIB = ' + ' '.join(l) + '\n')
-        slepcvars.write('PRIMME_INCLUDE = ' + ' '.join(f) + '\n')
-        self.havepackage = True
-        self.packageflags = l+f
-        self.location = includes[0] if self.packageincludes else i
-        return
+          l = libs
+          f = []
+        (result, output) = self.Link([],[],' '.join(l+f),code,' '.join(f),petsc.language)
+        if result:
+          self.libflags = ' '.join(l)
+          self.includeflags = ' '.join(f)
+          slepcconf.write('#define SLEPC_HAVE_PRIMME 1\n')
+          slepcvars.write('PRIMME_LIB = ' + self.libflags + '\n')
+          slepcvars.write('PRIMME_INCLUDE = ' + self.includeflags + '\n')
+          self.havepackage = True
+          self.packageflags = ' '.join(l+f)
+          self.location = includes[0] if self.packageincludes else i
+          if not self.location:
+            self.location = self.DefaultIncludePath(petsc,'primme.h')
+          return
 
     self.log.Exit('Unable to link with PRIMME library in directories'+' '.join(dirs)+' with libraries and link flags '+' '.join(libs)+' [NOTE: make sure PRIMME version is 2.0 at least]')
 
 
   def DownloadAndInstall(self,slepcconf,slepcvars,slepc,petsc,archdir,prefixdir):
-    externdir = slepc.CreateDir(archdir,'externalpackages')
+    externdir = slepc.GetExternalPackagesDir(archdir)
     builddir  = self.Download(externdir,slepc.downloaddir)
 
     # Makefile
     cont =  'export LIBRARY       = libprimme.'+petsc.ar_lib_suffix+'\n'
-    cont += 'export SOLIBRARY     = libprimme.'+petsc.sl_suffix+'\n'
-    cont += 'export SONAMELIBRARY = libprimme.'+petsc.sl_suffix+'.'+self.version+'\n'
+    cont += 'export SOLIBRARY     = libprimme.'+petsc.sl_linker_suffix+'\n'
+    cont += 'export SONAMELIBRARY = libprimme.'+petsc.sl_linker_suffix+'.'+self.version+'\n'
     cont += 'export CC            = '+petsc.cc+'\n'
     if hasattr(petsc,'fc'):
       cont += 'export F77           = '+petsc.fc+'\n'
@@ -124,7 +127,7 @@ class Primme(package.Package):
 
     # Build package
     target = ' install' if petsc.buildsharedlib else ' lib'
-    mymake = petsc.make + ' -f mymake_flags '
+    mymake = petsc.make + ' -j' + petsc.make_np + ' -f mymake_flags '
     (result, output) = self.RunCommand('cd '+builddir+'&&'+mymake+' clean && '+mymake+target)
     if result:
       self.log.Exit('Installation of PRIMME failed')
@@ -138,40 +141,42 @@ class Primme(package.Package):
           shutil.copyfile(os.path.join(builddir,'include',name),os.path.join(incdir,name))
 
     if petsc.buildsharedlib:
-      l = petsc.slflag + libdir + ' -L' + libdir + ' -lprimme'
+      l = self.slflag + libdir + ' -L' + libdir + ' -lprimme'
     else:
       l = '-L' + libdir + ' -lprimme'
     f = '-I' + incdir
 
     # Check build
     code = self.SampleCode(petsc)
-    (result, output) = self.Link([],[],[l]+[f],code,f,petsc.language)
+    (result, output) = self.Link([],[],l+' '+f,code,f,petsc.language)
     if not result:
       self.log.Exit('Unable to link with downloaded PRIMME')
 
     # Write configuration files
+    self.libflags = l
+    self.includeflags = f
     slepcconf.write('#define SLEPC_HAVE_PRIMME 1\n')
-    slepcvars.write('PRIMME_LIB = ' + l + '\n')
-    slepcvars.write('PRIMME_INCLUDE = ' + f + '\n')
+    slepcvars.write('PRIMME_LIB = ' + self.libflags + '\n')
+    slepcvars.write('PRIMME_INCLUDE = ' + self.includeflags + '\n')
 
     self.location = incdir
     self.havepackage = True
-    self.packageflags = [l] + [f]
+    self.packageflags = l+' '+f
 
 
   def LoadVersion(self,slepcconf):
     try:
-      f = open(os.path.join(self.location,'primme.h'))
-      for l in f.readlines():
-        l = l.split()
-        if len(l) == 3:
-          if l[1] == 'PRIMME_VERSION_MAJOR':
-            major = l[2]
-          elif l[1] == 'PRIMME_VERSION_MINOR':
-            minor = l[2]
-      f.close()
+      with open(os.path.join(self.location,'primme.h')) as f:
+        for l in f.readlines():
+          l = l.split()
+          if len(l) == 3:
+            if l[1] == 'PRIMME_VERSION_MAJOR':
+              major = l[2]
+            elif l[1] == 'PRIMME_VERSION_MINOR':
+              minor = l[2]
       self.iversion = major + '.' + minor
       if major=='3':
         slepcconf.write('#define SLEPC_HAVE_PRIMME3 1\n')
-    except: pass
+    except Exception as e:
+      self.log.write('Error while determining version of PRIMME:\n'+str(e))
 
