@@ -8,12 +8,13 @@
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 */
 
-#if !defined(SLEPCLMEIMPL_H)
-#define SLEPCLMEIMPL_H
+#pragma once
 
 #include <slepclme.h>
 #include <slepc/private/slepcimpl.h>
 
+/* SUBMANSEC = LME */
+
 SLEPC_EXTERN PetscBool LMERegisterAllCalled;
 SLEPC_EXTERN PetscBool LMEMonitorRegisterAllCalled;
 SLEPC_EXTERN PetscErrorCode LMERegisterAll(void);
@@ -25,7 +26,7 @@ typedef struct _LMEOps *LMEOps;
 struct _LMEOps {
   PetscErrorCode (*solve[sizeof(LMEProblemType)])(LME);
   PetscErrorCode (*setup)(LME);
-  PetscErrorCode (*setfromoptions)(PetscOptionItems*,LME);
+  PetscErrorCode (*setfromoptions)(LME,PetscOptionItems*);
   PetscErrorCode (*publishoptions)(LME);
   PetscErrorCode (*destroy)(LME);
   PetscErrorCode (*reset)(LME);
@@ -106,5 +107,3 @@ SLEPC_EXTERN void SLEPC_SLICOT(sb03od,SB03OD)(const char*,const char*,const char
 SLEPC_EXTERN void SLEPC_SLICOT(sb03md,SB03MD)(const char*,const char*,const char*,const char*,PetscBLASInt*,PetscScalar*,PetscBLASInt*,PetscScalar*,PetscBLASInt*,PetscScalar*,PetscBLASInt*,PetscReal*,PetscReal*,PetscReal*,PetscScalar*,PetscScalar*,PetscBLASInt*,PetscReal*,PetscBLASInt*,PetscBLASInt*,PetscBLASInt,PetscBLASInt,PetscBLASInt,PetscBLASInt);
 
 #endif
-
-#endif
