@@ -11,10 +11,12 @@
    User interface for various vector operations added in SLEPc
 */
 
-#if !defined(SLEPCVEC_H)
-#define SLEPCVEC_H
+#pragma once
+
 #include <slepcsys.h>
 
+/* SUBMANSEC = sys */
+
 /* VecComp: Vec composed of several smaller Vecs */
 #define VECCOMP  "comp"
 
@@ -31,8 +33,5 @@ SLEPC_EXTERN PetscErrorCode VecDuplicateEmpty(Vec,Vec*);
 SLEPC_EXTERN PetscErrorCode VecSetRandomNormal(Vec,PetscRandom,Vec,Vec);
 
 /* Deprecated functions */
-PETSC_DEPRECATED_FUNCTION("Use VecNormalizeComplex()") static inline PetscErrorCode SlepcVecNormalize(Vec xr,Vec xi,PetscBool c,PetscReal *nrm) {return VecNormalizeComplex(xr,xi,c,nrm);}
-PETSC_DEPRECATED_FUNCTION("Use VecCheckOrthogonality()") static inline PetscErrorCode SlepcCheckOrthogonality(Vec *V,PetscInt nv,Vec *W,PetscInt nw,Mat B,PetscViewer viewer,PetscReal *lev) {return VecCheckOrthogonality(V,nv,W,nw,B,viewer,lev);}
-
-#endif
-
+PETSC_DEPRECATED_FUNCTION(3, 8, 0, "VecNormalizeComplex()", ) static inline PetscErrorCode SlepcVecNormalize(Vec xr,Vec xi,PetscBool c,PetscReal *nrm) {return VecNormalizeComplex(xr,xi,c,nrm);}
+PETSC_DEPRECATED_FUNCTION(3, 8, 0, "VecCheckOrthogonality()", ) static inline PetscErrorCode SlepcCheckOrthogonality(Vec *V,PetscInt nv,Vec *W,PetscInt nw,Mat B,PetscViewer viewer,PetscReal *lev) {return VecCheckOrthogonality(V,nv,W,nw,B,viewer,lev);}
