@@ -8,22 +8,22 @@
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 */
 
-#if !defined(SLEPCVERSION_H)
+#ifndef SLEPCVERSION_H
 #define SLEPCVERSION_H
 
 #define SLEPC_VERSION_RELEASE    1
 #define SLEPC_VERSION_MAJOR      3
-#define SLEPC_VERSION_MINOR      19
+#define SLEPC_VERSION_MINOR      22
 #define SLEPC_VERSION_SUBMINOR   1
-#define SLEPC_RELEASE_DATE       "March 31, 2023"
-#define SLEPC_VERSION_DATE       "May 15, 2023"
+#define SLEPC_RELEASE_DATE       "September 29, 2024"
+#define SLEPC_VERSION_DATE       "Oct 28, 2024"
 
 #if !defined (SLEPC_VERSION_GIT)
-#define SLEPC_VERSION_GIT        "v3.19.1"
+#define SLEPC_VERSION_GIT        "v3.22.1"
 #endif
 
 #if !defined(SLEPC_VERSION_DATE_GIT)
-#define SLEPC_VERSION_DATE_GIT   "2023-05-15 10:41:44 +0200"
+#define SLEPC_VERSION_DATE_GIT   "2024-10-28 09:43:32 +0100"
 #endif
 
 #define SLEPC_VERSION_EQ(MAJOR,MINOR,SUBMINOR) \
@@ -53,4 +53,3 @@
   (0 == SLEPC_VERSION_LT(MAJOR,MINOR,SUBMINOR))
 
 #endif
-
