@@ -22,9 +22,9 @@
 PetscErrorCode EPSSetDefaultST(EPS eps)
 {
   PetscFunctionBegin;
-  if (eps->ops->setdefaultst) PetscCall((*eps->ops->setdefaultst)(eps));
+  PetscTryTypeMethod(eps,setdefaultst);
   if (!((PetscObject)eps->st)->type_name) PetscCall(STSetType(eps->st,STSHIFT));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*
@@ -39,7 +39,7 @@ PetscErrorCode EPSSetDefaultST_Precond(EPS eps)
   if (!((PetscObject)eps->st)->type_name) PetscCall(STSetType(eps->st,STPRECOND));
   PetscCall(STGetKSP(eps->st,&ksp));
   if (!((PetscObject)ksp)->type_name) PetscCall(KSPSetType(ksp,KSPPREONLY));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*
@@ -56,9 +56,9 @@ PetscErrorCode EPSSetDefaultST_GMRES(EPS eps)
   PetscCall(STGetKSP(eps->st,&ksp));
   if (!((PetscObject)ksp)->type_name) {
     PetscCall(KSPSetType(ksp,KSPGMRES));
-    PetscCall(KSPSetTolerances(ksp,PETSC_DEFAULT,PETSC_DEFAULT,PETSC_DEFAULT,5));
+    PetscCall(KSPSetTolerances(ksp,PETSC_CURRENT,PETSC_CURRENT,PETSC_CURRENT,5));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 #if defined(SLEPC_HAVE_SCALAPACK) || defined(SLEPC_HAVE_ELPA) || defined(SLEPC_HAVE_ELEMENTAL) || defined(SLEPC_HAVE_EVSL)
@@ -77,14 +77,14 @@ PetscErrorCode EPSSetDefaultST_NoFactor(EPS eps)
   if (!((PetscObject)ksp)->type_name) PetscCall(KSPSetType(ksp,KSPPREONLY));
   PetscCall(KSPGetPC(ksp,&pc));
   if (!((PetscObject)pc)->type_name) PetscCall(PCSetType(pc,PCNONE));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 #endif
 
 /*
    Check that the ST selected by the user is compatible with the EPS solver and options
 */
-PetscErrorCode EPSCheckCompatibleST(EPS eps)
+static PetscErrorCode EPSCheckCompatibleST(EPS eps)
 {
   PetscBool      precond,shift,sinvert,cayley,lyapii;
 #if defined(PETSC_USE_COMPLEX)
@@ -118,7 +118,7 @@ PetscErrorCode EPSCheckCompatibleST(EPS eps)
     PetscCall(PetscObjectTypeCompare((PetscObject)eps,EPSLYAPII,&lyapii));
     PetscCheck(lyapii || eps->which==EPS_TARGET_MAGNITUDE || eps->which==EPS_TARGET_REAL || eps->which==EPS_TARGET_IMAGINARY || eps->which==EPS_ALL || eps->which==EPS_WHICH_USER,PetscObjectComm((PetscObject)eps),PETSC_ERR_USER_INPUT,"Shift-and-invert requires a target 'which' (see EPSSetWhichEigenpairs), for instance -st_type sinvert -eps_target 0 -eps_target_magnitude");
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*
@@ -157,7 +157,7 @@ PetscErrorCode MatEstimateSpectralRange_EPS(Mat A,PetscReal *left,PetscReal *rig
   } else eig0 = eps->eigr[0];
   *right = PetscRealPart(eig0)+errest;
   PetscCall(EPSDestroy(&eps));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*
@@ -214,7 +214,7 @@ PetscErrorCode EPSSetUpSort_Basic(EPS eps)
   }
   eps->sc->map    = NULL;
   eps->sc->mapobj = NULL;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*
@@ -236,7 +236,32 @@ PetscErrorCode EPSSetUpSort_Default(EPS eps)
   sc->comparisonctx = eps->sc->comparisonctx;
   sc->map           = SlepcMap_ST;
   sc->mapobj        = (PetscObject)eps->st;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
+}
+
+/*@
+   EPSSetDSType - Sets the type of the internal DS object based on the current
+   settings of the eigenvalue solver.
+
+   Collective
+
+   Input Parameter:
+.  eps - eigenproblem solver context
+
+   Note:
+   This function need not be called explicitly, since it will be called at
+   both EPSSetFromOptions() and EPSSetUp().
+
+   Level: developer
+
+.seealso: EPSSetFromOptions(), EPSSetUp()
+@*/
+PetscErrorCode EPSSetDSType(EPS eps)
+{
+  PetscFunctionBegin;
+  PetscValidHeaderSpecific(eps,EPS_CLASSID,1);
+  PetscTryTypeMethod(eps,setdstype);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -244,7 +269,7 @@ PetscErrorCode EPSSetUpSort_Default(EPS eps)
    execution of the eigensolver. Then calls STSetUp() for any set-up
    operations associated to the ST object.
 
-   Collective on eps
+   Collective
 
    Input Parameter:
 .  eps   - eigenproblem solver context
@@ -266,7 +291,7 @@ PetscErrorCode EPSSetUp(EPS eps)
 
   PetscFunctionBegin;
   PetscValidHeaderSpecific(eps,EPS_CLASSID,1);
-  if (eps->state) PetscFunctionReturn(0);
+  if (eps->state) PetscFunctionReturn(PETSC_SUCCESS);
   PetscCall(PetscLogEventBegin(EPS_SetUp,eps,0,0,0));
 
   /* reset the convergence flag from the previous solves */
@@ -278,7 +303,9 @@ PetscErrorCode EPSSetUp(EPS eps)
   PetscCall(EPSSetDefaultST(eps));
 
   PetscCall(STSetTransform(eps->st,PETSC_TRUE));
+  PetscCall(STSetStructured(eps->st,PETSC_FALSE));
   if (eps->useds && !eps->ds) PetscCall(EPSGetDS(eps,&eps->ds));
+  if (eps->useds) PetscCall(EPSSetDSType(eps));
   if (eps->twosided) {
     PetscCheck(!eps->ishermitian || (eps->isgeneralized && !eps->ispositive),PetscObjectComm((PetscObject)eps),PETSC_ERR_SUP,"Two-sided methods are not intended for %s problems",SLEPC_STRING_HERMITIAN);
   }
@@ -301,6 +328,12 @@ PetscErrorCode EPSSetUp(EPS eps)
     eps->problem_type = eps->ishermitian? EPS_HEP: EPS_NHEP;
   } else PetscCheck(nmat==1 || eps->isgeneralized,PetscObjectComm((PetscObject)eps),PETSC_ERR_ARG_INCOMP,"Inconsistent EPS state: the problem type does not match the number of matrices");
 
+  if (eps->isstructured) {
+    /* make sure the user has set the appropriate matrix */
+    PetscCall(STGetMatrix(eps->st,0,&A));
+    if (eps->problem_type==EPS_BSE) PetscCall(SlepcCheckMatStruct(A,SLEPC_MAT_STRUCT_BSE,NULL));
+  }
+
   if (eps->nev > eps->n) eps->nev = eps->n;
   if (eps->ncv > eps->n) eps->ncv = eps->n;
 
@@ -320,7 +353,7 @@ PetscErrorCode EPSSetUp(EPS eps)
   }
 
   /* call specific solver setup */
-  PetscCall((*eps->ops->setup)(eps));
+  PetscUseTypeMethod(eps,setup);
 
   /* if purification is set, check that it really makes sense */
   if (eps->purify) {
@@ -336,19 +369,16 @@ PetscErrorCode EPSSetUp(EPS eps)
   }
 
   /* set tolerance if not yet set */
-  if (eps->tol==PETSC_DEFAULT) eps->tol = SLEPC_DEFAULT_TOL;
+  if (eps->tol==(PetscReal)PETSC_DETERMINE) eps->tol = SLEPC_DEFAULT_TOL;
 
   /* set up sorting criterion */
-  if (eps->ops->setupsort) PetscCall((*eps->ops->setupsort)(eps));
+  PetscTryTypeMethod(eps,setupsort);
 
   /* Build balancing matrix if required */
   if (eps->balance!=EPS_BALANCE_USER) {
     PetscCall(STSetBalanceMatrix(eps->st,NULL));
     if (!eps->ishermitian && (eps->balance==EPS_BALANCE_ONESIDE || eps->balance==EPS_BALANCE_TWOSIDE)) {
-      if (!eps->D) {
-        PetscCall(BVCreateVec(eps->V,&eps->D));
-        PetscCall(PetscLogObjectParent((PetscObject)eps,(PetscObject)eps->D));
-      }
+      if (!eps->D) PetscCall(BVCreateVec(eps->V,&eps->D));
       PetscCall(EPSBuildBalance_Krylov(eps));
       PetscCall(STSetBalanceMatrix(eps->st,eps->D));
     }
@@ -360,6 +390,7 @@ PetscErrorCode EPSSetUp(EPS eps)
 
   /* process deflation and initial vectors */
   if (eps->nds<0) {
+    PetscCheck(!eps->isstructured,PetscObjectComm((PetscObject)eps),PETSC_ERR_SUP,"Deflation space is not supported in structured eigenproblems");
     k = -eps->nds;
     PetscCall(BVInsertConstraints(eps->V,&k,eps->defl));
     PetscCall(SlepcBasisDestroy_Private(&eps->nds,&eps->defl));
@@ -383,13 +414,13 @@ PetscErrorCode EPSSetUp(EPS eps)
 
   PetscCall(PetscLogEventEnd(EPS_SetUp,eps,0,0,0));
   eps->state = EPS_STATE_SETUP;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    EPSSetOperators - Sets the matrices associated with the eigenvalue problem.
 
-   Collective on eps
+   Collective
 
    Input Parameters:
 +  eps - the eigenproblem solver context
@@ -402,9 +433,13 @@ PetscErrorCode EPSSetUp(EPS eps)
    It must be called before EPSSetUp(). If it is called again after EPSSetUp() and
    the matrix sizes have changed then the EPS object is reset.
 
+   For structured eigenproblem types such as EPS_BSE (see EPSSetProblemType()), the
+   provided matrices must have been created with the corresponding helper function,
+   i.e., MatCreateBSE().
+
    Level: beginner
 
-.seealso: EPSSolve(), EPSSetUp(), EPSReset(), EPSGetST(), STGetMatrix()
+.seealso: EPSSolve(), EPSSetUp(), EPSReset(), EPSGetST(), STGetMatrix(), EPSSetProblemType()
 @*/
 PetscErrorCode EPSSetOperators(EPS eps,Mat A,Mat B)
 {
@@ -442,13 +477,13 @@ PetscErrorCode EPSSetOperators(EPS eps,Mat A,Mat B)
   } else nmat = 1;
   PetscCall(STSetMatrices(eps->st,nmat,mat));
   eps->state = EPS_STATE_INITIAL;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    EPSGetOperators - Gets the matrices associated with the eigensystem.
 
-   Collective on eps
+   Collective
 
    Input Parameter:
 .  eps - the EPS context
@@ -481,14 +516,14 @@ PetscErrorCode EPSGetOperators(EPS eps,Mat *A,Mat *B)
     if (k<2) *B = NULL;
     else PetscCall(STGetMatrix(st,1,B));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-/*@C
+/*@
    EPSSetDeflationSpace - Specify a basis of vectors that constitute the deflation
    space.
 
-   Collective on eps
+   Collective
 
    Input Parameters:
 +  eps - the eigenproblem solver context
@@ -518,19 +553,19 @@ PetscErrorCode EPSSetDeflationSpace(EPS eps,PetscInt n,Vec v[])
   PetscValidLogicalCollectiveInt(eps,n,2);
   PetscCheck(n>=0,PetscObjectComm((PetscObject)eps),PETSC_ERR_ARG_OUTOFRANGE,"Argument n cannot be negative");
   if (n>0) {
-    PetscValidPointer(v,3);
+    PetscAssertPointer(v,3);
     PetscValidHeaderSpecific(*v,VEC_CLASSID,3);
   }
   PetscCall(SlepcBasisReference_Private(n,v,&eps->nds,&eps->defl));
   if (n>0) eps->state = EPS_STATE_INITIAL;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-/*@C
+/*@
    EPSSetInitialSpace - Specify a basis of vectors that constitute the initial
    space, that is, the subspace from which the solver starts to iterate.
 
-   Collective on eps
+   Collective
 
    Input Parameters:
 +  eps - the eigenproblem solver context
@@ -561,19 +596,19 @@ PetscErrorCode EPSSetInitialSpace(EPS eps,PetscInt n,Vec is[])
   PetscValidLogicalCollectiveInt(eps,n,2);
   PetscCheck(n>=0,PetscObjectComm((PetscObject)eps),PETSC_ERR_ARG_OUTOFRANGE,"Argument n cannot be negative");
   if (n>0) {
-    PetscValidPointer(is,3);
+    PetscAssertPointer(is,3);
     PetscValidHeaderSpecific(*is,VEC_CLASSID,3);
   }
   PetscCall(SlepcBasisReference_Private(n,is,&eps->nini,&eps->IS));
   if (n>0) eps->state = EPS_STATE_INITIAL;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-/*@C
+/*@
    EPSSetLeftInitialSpace - Specify a basis of vectors that constitute the left
    initial space, used by two-sided solvers to start the left subspace.
 
-   Collective on eps
+   Collective
 
    Input Parameters:
 +  eps - the eigenproblem solver context
@@ -598,12 +633,12 @@ PetscErrorCode EPSSetLeftInitialSpace(EPS eps,PetscInt n,Vec isl[])
   PetscValidLogicalCollectiveInt(eps,n,2);
   PetscCheck(n>=0,PetscObjectComm((PetscObject)eps),PETSC_ERR_ARG_OUTOFRANGE,"Argument n cannot be negative");
   if (n>0) {
-    PetscValidPointer(isl,3);
+    PetscAssertPointer(isl,3);
     PetscValidHeaderSpecific(*isl,VEC_CLASSID,3);
   }
   PetscCall(SlepcBasisReference_Private(n,isl,&eps->ninil,&eps->ISL));
   if (n>0) eps->state = EPS_STATE_INITIAL;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*
@@ -615,14 +650,14 @@ PetscErrorCode EPSSetDimensions_Default(EPS eps,PetscInt nev,PetscInt *ncv,Petsc
   PetscBool      krylov;
 
   PetscFunctionBegin;
-  if (*ncv!=PETSC_DEFAULT) { /* ncv set */
+  if (*ncv!=PETSC_DETERMINE) { /* ncv set */
     PetscCall(PetscObjectTypeCompareAny((PetscObject)eps,&krylov,EPSKRYLOVSCHUR,EPSARNOLDI,EPSLANCZOS,""));
     if (krylov) {
       PetscCheck(*ncv>=nev+1 || (*ncv==nev && *ncv==eps->n),PetscObjectComm((PetscObject)eps),PETSC_ERR_USER_INPUT,"The value of ncv must be at least nev+1");
     } else {
       PetscCheck(*ncv>=nev,PetscObjectComm((PetscObject)eps),PETSC_ERR_USER_INPUT,"The value of ncv must be at least nev");
     }
-  } else if (*mpd!=PETSC_DEFAULT) { /* mpd set */
+  } else if (*mpd!=PETSC_DETERMINE) { /* mpd set */
     *ncv = PetscMin(eps->n,nev+(*mpd));
   } else { /* neither set: defaults depend on nev being small or large */
     if (nev<500) *ncv = PetscMin(eps->n,PetscMax(2*nev,nev+15));
@@ -631,15 +666,15 @@ PetscErrorCode EPSSetDimensions_Default(EPS eps,PetscInt nev,PetscInt *ncv,Petsc
       *ncv = PetscMin(eps->n,nev+(*mpd));
     }
   }
-  if (*mpd==PETSC_DEFAULT) *mpd = *ncv;
-  PetscFunctionReturn(0);
+  if (*mpd==PETSC_DETERMINE) *mpd = *ncv;
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    EPSAllocateSolution - Allocate memory storage for common variables such
    as eigenvalues and eigenvectors.
 
-   Collective on eps
+   Collective
 
    Input Parameters:
 +  eps   - eigensolver context
@@ -656,8 +691,7 @@ PetscErrorCode EPSSetDimensions_Default(EPS eps,PetscInt nev,PetscInt *ncv,Petsc
 @*/
 PetscErrorCode EPSAllocateSolution(EPS eps,PetscInt extra)
 {
-  PetscInt       oldsize,newc,requested;
-  PetscLogDouble cnt;
+  PetscInt       oldsize,requested;
   PetscRandom    rand;
   Vec            t;
 
@@ -666,27 +700,23 @@ PetscErrorCode EPSAllocateSolution(EPS eps,PetscInt extra)
 
   /* oldsize is zero if this is the first time setup is called */
   PetscCall(BVGetSizes(eps->V,NULL,NULL,&oldsize));
-  newc = PetscMax(0,requested-oldsize);
 
   /* allocate space for eigenvalues and friends */
   if (requested != oldsize || !eps->eigr) {
     PetscCall(PetscFree4(eps->eigr,eps->eigi,eps->errest,eps->perm));
     PetscCall(PetscMalloc4(requested,&eps->eigr,requested,&eps->eigi,requested,&eps->errest,requested,&eps->perm));
-    cnt = 2*newc*sizeof(PetscScalar) + 2*newc*sizeof(PetscReal) + newc*sizeof(PetscInt);
-    PetscCall(PetscLogObjectMemory((PetscObject)eps,cnt));
   }
 
   /* workspace for the case of arbitrary selection */
   if (eps->arbitrary) {
     if (eps->rr) PetscCall(PetscFree2(eps->rr,eps->ri));
     PetscCall(PetscMalloc2(requested,&eps->rr,requested,&eps->ri));
-    PetscCall(PetscLogObjectMemory((PetscObject)eps,2*newc*sizeof(PetscScalar)));
   }
 
   /* allocate V */
   if (!eps->V) PetscCall(EPSGetBV(eps,&eps->V));
   if (!oldsize) {
-    if (!((PetscObject)(eps->V))->type_name) PetscCall(BVSetType(eps->V,BVSVEC));
+    if (!((PetscObject)eps->V)->type_name) PetscCall(BVSetType(eps->V,BVMAT));
     PetscCall(STMatCreateVecsEmpty(eps->st,&t,NULL));
     PetscCall(BVSetSizesFromVec(eps->V,t,requested));
     PetscCall(VecDestroy(&t));
@@ -698,5 +728,5 @@ PetscErrorCode EPSAllocateSolution(EPS eps,PetscInt extra)
     PetscCall(BVDestroy(&eps->W));
     PetscCall(BVDuplicate(eps->V,&eps->W));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
