@@ -41,7 +41,7 @@ int main(int argc,char **argv)
   PetscScalar    coeffs;
 
   PetscFunctionBeginUser;
-  PetscCall(SlepcInitialize(&argc,&argv,(char*)0,help));
+  PetscCall(SlepcInitialize(&argc,&argv,NULL,help));
   PetscCall(PetscOptionsGetInt(NULL,NULL,"-n",&n,NULL));
   PetscCall(PetscOptionsGetBool(NULL,NULL,"-split",&split,NULL));
   PetscCall(PetscPrintf(PETSC_COMM_WORLD,"\nSquare root eigenproblem, n=%" PetscInt_FMT "%s\n\n",n,split?" (in split form)":""));
@@ -78,7 +78,6 @@ int main(int argc,char **argv)
     PetscCall(MatCreate(PETSC_COMM_WORLD,&A[0]));
     PetscCall(MatSetSizes(A[0],PETSC_DECIDE,PETSC_DECIDE,n,n));
     PetscCall(MatSetFromOptions(A[0]));
-    PetscCall(MatSetUp(A[0]));
     PetscCall(MatGetOwnershipRange(A[0],&Istart,&Iend));
     for (i=Istart;i<Iend;i++) {
       if (i>0) PetscCall(MatSetValue(A[0],i,i-1,1.0,INSERT_VALUES));
@@ -110,7 +109,6 @@ int main(int argc,char **argv)
     PetscCall(MatSetFromOptions(F));
     PetscCall(MatSeqAIJSetPreallocation(F,3,NULL));
     PetscCall(MatMPIAIJSetPreallocation(F,3,NULL,1,NULL));
-    PetscCall(MatSetUp(F));
     PetscCall(NEPSetFunction(nep,F,F,FormFunction,NULL));
 
     PetscCall(MatCreate(PETSC_COMM_WORLD,&J));
@@ -118,7 +116,6 @@ int main(int argc,char **argv)
     PetscCall(MatSetFromOptions(J));
     PetscCall(MatSeqAIJSetPreallocation(J,1,NULL));
     PetscCall(MatMPIAIJSetPreallocation(J,1,NULL,1,NULL));
-    PetscCall(MatSetUp(J));
     PetscCall(NEPSetJacobian(nep,J,FormJacobian,NULL));
   }
 
@@ -257,9 +254,13 @@ PetscErrorCode ComputeSingularities(NEP nep,PetscInt *maxnp,PetscScalar *xi,void
          suffix: 3
          args: -nep_tol 1e-8 -nep_nleigs_rk_shifts 1.06,1.1,1.12,1.15 -nep_conv_norm -nep_nleigs_interpolation_degree 20
       test:
-         suffix: 5
+         suffix: 5_cuda
          args: -mat_type aijcusparse
          requires: cuda
+      test:
+         suffix: 5_hip
+         args: -mat_type aijhipsparse
+         requires: hip
 
    testset:
       args: -split 0 -nep_nev 3 -terse
@@ -274,9 +275,13 @@ PetscErrorCode ComputeSingularities(NEP nep,PetscInt *maxnp,PetscScalar *xi,void
          args: -nep_nleigs_rk_shifts 1.06,1.1,1.12,1.15 -nep_nleigs_interpolation_degree 20
          requires: double
       test:
-         suffix: 6
+         suffix: 6_cuda
          args: -mat_type aijcusparse
          requires: cuda !single
+      test:
+         suffix: 6_hip
+         args: -mat_type aijhipsparse
+         requires: hip !single
 
    testset:
       args: -split 0 -nep_type ciss -nep_ciss_extraction {{ritz hankel caa}} -rg_type ellipse -rg_ellipse_center 8 -rg_ellipse_radius .7 -nep_ciss_moments 4 -rg_ellipse_vscale 0.1 -terse
